@@ -14,10 +14,8 @@ ASSET_DIR_IN_PROG = Path(__file__).parent.absolute().joinpath("assets")
 CLOCK_DIR_IN_PROG = ASSET_DIR_IN_PROG / "clock"
 SOUND_DIR_IN_PROG = ASSET_DIR_IN_PROG / "sound"
 ASSET_DIR_IN_SYS = Path(Path.home(), ".exclock")
-CLOCK_DIR_IN_SYS = ASSET_DIR_IN_SYS / "clock"
-SOUND_DIR_IN_SYS = ASSET_DIR_IN_SYS / "sound"
-
-DEFAULT_IMAGE_PATH = ASSET_DIR_IN_PROG / "icon.png"
+CLOCK_DIR_IN_SYS = Path(os.getenv('EXCLOCK_CLOCK_DIR', str(ASSET_DIR_IN_SYS / "clock"))).absolute()
+SOUND_DIR_IN_SYS = Path(os.getenv('EXCLOCK_SOUND_DIR', str(ASSET_DIR_IN_SYS / "sound"))).absolute()
 
 
 def get_clock_basenames() -> List[str]:
@@ -148,7 +146,7 @@ def get_real_sound_filename(path_: str) -> str:
 
 def notify(title: str, message: str) -> None:
     message = quote(title + "\n" + message)
-    os.system(f'(xmessage -nearmouse {message}) &')
+    os.system(f'(xmessage -nearmouse -timeout 20 -buttons Close {message}) &')
 
 
 def notify_all(
@@ -164,3 +162,5 @@ def notify_all(
 
     if not is_first:
         notify(title=title, message=message)
+
+    print(message)
